'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var styleInject = _interopDefault(require('./node_modules/style-inject/dist/style-inject.es.js'));
var __vue_normalize__ = _interopDefault(require('vue-runtime-helpers/dist/normalize-component.js'));

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script = {
  name: 'TinyPagination',
  props: {
    total: {
      type: Number,
      required: true
    },
    page: {
      type: Number,
      "default": 1
    },
    lang: {
      type: String,
      "default": 'en'
    },
    customClass: {
      type: String,
      "default": ''
    },
    limits: {
      type: Array,
      "default": function _default() {
        return [10, 15, 20, 50, 100];
      }
    },
    showLimit: {
      type: Boolean,
      "default": true
    }
  },
  data: function data() {
    return {
      version: '0.3.2',
      currentPage: 1,
      currentLimit: 10,
      translations: {
        en: {
          prev: 'Previous',
          title: 'Page',
          next: 'Next'
        },
        es: {
          prev: 'Anterior',
          title: 'Página',
          next: 'Siguiente'
        }
      },
      availableLanguages: ['en', 'es']
    };
  },
  computed: {
    translation: function translation() {
      return this.availableLanguages.includes(this.lang) ? this.translations[this.lang] : this.translations.en;
    },
    totalPages: function totalPages() {
      return Math.ceil(this.total / this.currentLimit);
    },
    titlePage: function titlePage() {
      return "".concat(this.translation.title, " ").concat(this.currentPage);
    },
    classFirstPage: function classFirstPage() {
      return {
        disabled: this.currentPage === 1,
        'c-not-allowed': true
      };
    },
    classLastPage: function classLastPage() {
      return {
        disabled: this.currentPage === this.totalPages,
        'c-not-allowed': true
      };
    }
  },
  watch: {
    currentPage: function currentPage(value) {
      this.$emit('tiny:change-page', {
        page: value
      });
    },
    currentLimit: function currentLimit(value) {
      this.$emit('tiny:change-limit', {
        limit: value
      });
    }
  },
  created: function created() {
    this.currentPage = this.page;
  },
  methods: {
    nextPage: function nextPage() {
      if (this.currentPage !== this.totalPages) {
        this.currentPage += 1;
      }
    },
    lastPage: function lastPage() {
      if (this.currentPage > 1) {
        this.currentPage -= 1;
      }
    },
    onLimitChange: function onLimitChange() {
      this.currentPage = 1;
    }
  }
};

var css = "@charset \"UTF-8\";.tiny-pagination{font-family:-apple-system,system-ui,BlinkMacSystemFont,\"Segoe UI\",Roboto,\"Helvetica Neue\",sans-serif;display:flex;list-style:none;margin:.2rem 0;padding:.2rem 0}.tiny-pagination .page-item{margin:.2rem .05rem}.tiny-pagination .page-item span{display:inline-block;padding:.2rem .2rem}.tiny-pagination .page-item a{border-radius:.1rem;color:#667189;display:inline-block;padding:.2rem .4rem;text-decoration:none}.tiny-pagination .page-item a:focus,.tiny-pagination .page-item a:hover{color:#5755d9}.tiny-pagination .page-item.disabled a{cursor:default;opacity:.5;pointer-events:none}.tiny-pagination .page-item.active a{background:#5755d9;color:#fff}.tiny-pagination .page-item.page-next,.tiny-pagination .page-item.page-prev{flex:1 0 50%}.tiny-pagination .page-item.page-next{text-align:right}.tiny-pagination .page-item .page-item-title{margin:0}.tiny-pagination .page-item .page-item-subtitle{margin:0;opacity:.5}.tiny-pagination .tiny-form-select{-webkit-appearance:none;-moz-appearance:none;appearance:none;text-transform:lowercase;border:.05rem solid #caced7;border-radius:.1rem;font-size:.8rem;height:1.8rem;line-height:1rem;outline:0;padding:.35rem .4rem;vertical-align:middle;width:100%}.tiny-pagination .tiny-form-select:focus{border-color:#5755d9;box-shadow:0 0 0 .1rem rgba(87,85,217,.2)}.tiny-pagination .tiny-form-select:not([multiple]):not([size]){background:#fff url('data:image/svg+xml;charset=utf8,%3Csvg%20xmlns=\"http://www.w3.org/2000/svg\"…path%20fill=\"%23667189\"%20d=\"M2%200L0%202h4zm0%205L0%203h4z\"/%3E%3C/svg%3E') no-repeat right .35rem center/.4rem .5rem;padding-right:1.2rem}";
styleInject(css);

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "vue-tiny-pagination"
  }, [_c('ul', {
    staticClass: "tiny-pagination",
    "class": _vm.customClass
  }, [_c('li', {
    staticClass: "page-item",
    "class": _vm.classFirstPage
  }, [_c('a', {
    staticClass: "btn-prev-page",
    attrs: {
      "href": "#"
    },
    on: {
      "click": function click($event) {
        $event.preventDefault();
        return _vm.lastPage($event);
      }
    }
  }, [_vm._v(_vm._s(_vm.translation.prev))])]), _vm._v(" "), _c('li', {
    staticClass: "page-item"
  }, [_c('span', [_vm._v(_vm._s(_vm.titlePage))])]), _vm._v(" "), _c('li', {
    staticClass: "page-item",
    "class": _vm.classLastPage
  }, [_c('a', {
    staticClass: "btn-next-page",
    attrs: {
      "href": "#"
    },
    on: {
      "click": function click($event) {
        $event.preventDefault();
        return _vm.nextPage($event);
      }
    }
  }, [_vm._v(_vm._s(_vm.translation.next))])]), _vm._v(" "), _vm.showLimit ? _c('li', {
    staticClass: "page-item"
  }, [_c('select', {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.currentLimit,
      expression: "currentLimit"
    }],
    staticClass: "tiny-form-select",
    on: {
      "change": [function ($event) {
        var $$selectedVal = Array.prototype.filter.call($event.target.options, function (o) {
          return o.selected;
        }).map(function (o) {
          var val = "_value" in o ? o._value : o.value;
          return val;
        });
        _vm.currentLimit = $event.target.multiple ? $$selectedVal : $$selectedVal[0];
      }, _vm.onLimitChange]
    }
  }, _vm._l(_vm.limits, function (limit, index) {
    return _c('option', {
      key: index,
      domProps: {
        "value": limit
      }
    }, [_vm._v(_vm._s(limit) + "/" + _vm._s(_vm.translation.title))]);
  }), 0)]) : _vm._e()])]);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

var TinyPagination = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, undefined, undefined);

TinyPagination.install = function (Vue) {
  Vue.component(TinyPagination.name, TinyPagination);
};

var install = function install(Vue) {
  Vue.component(TinyPagination.name, TinyPagination);
};

if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue);
}

var index = {
  version: '0.3.2',
  install: install,
  TinyPagination: TinyPagination
};

module.exports = index;
